summaryrefslogtreecommitdiff
path: root/pow_z.c
diff options
context:
space:
mode:
authorpelissip <pelissip@280ebfd0-de03-0410-8827-d642c229c3f4>2005-02-03 14:33:31 +0000
committerpelissip <pelissip@280ebfd0-de03-0410-8827-d642c229c3f4>2005-02-03 14:33:31 +0000
commit62046052c1dc3667d6a1e863c362fbd3efa44860 (patch)
treefbcf47b298646aad75a01292a6b3b872d3a33346 /pow_z.c
parent34bb3fcfda03b7f8de6dff6f1088193789fd80c6 (diff)
downloadmpfr-62046052c1dc3667d6a1e863c362fbd3efa44860.tar.gz
Rename internal functions mpfr_set_overflow in mpfr_overflow and
mpfr_set_underflow in mpfr_underflow so that we can add new functions mpfr_set_underflow and mpfr_set_overflow (which set the global flags). git-svn-id: svn://scm.gforge.inria.fr/svn/mpfr/trunk@3269 280ebfd0-de03-0410-8827-d642c229c3f4
Diffstat (limited to 'pow_z.c')
-rw-r--r--pow_z.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/pow_z.c b/pow_z.c
index 8d1e90193..1f324e4a7 100644
--- a/pow_z.c
+++ b/pow_z.c
@@ -73,14 +73,14 @@ mpfr_pow_pos_z (mpfr_ptr y, mpfr_srcptr x, mpz_srcptr z, mp_rnd_t rnd)
/* Check Overflow */
if (MPFR_UNLIKELY (mpfr_overflow_p ()))
- return mpfr_set_overflow (y, rnd,
+ return mpfr_overflow (y, rnd,
mpz_odd_p (absz) ? MPFR_SIGN (x) : MPFR_SIGN_POS);
/* Check Underflow */
else if (MPFR_UNLIKELY (mpfr_underflow_p ()))
{
if (rnd == GMP_RNDN)
rnd = GMP_RNDZ;
- return mpfr_set_underflow (y, rnd,
+ return mpfr_underflow (y, rnd,
mpz_odd_p (absz) ? MPFR_SIGN (x) : MPFR_SIGN_POS);
}
return inexact;
@@ -160,7 +160,7 @@ mpfr_pow_z (mpfr_ptr y, mpfr_srcptr x, mpz_srcptr z, mp_rnd_t rnd)
if (MPFR_UNLIKELY (mpz_cmp_si (tmp, __gmpfr_emin) < 0))
{
/* The following test is necessary because in the rounding to the
* nearest mode, mpfr_set_underflow always rounds away from 0. In
* this rounding mode, we need to round to 0 if:
* _ |y| < 2^(emin-2), or
* _ |y| = 2^(emin-2) and the absolute value of the exact
@@ -169,10 +169,10 @@ mpfr_pow_z (mpfr_ptr y, mpfr_srcptr x, mpz_srcptr z, mp_rnd_t rnd)
*/
if (rnd == GMP_RNDN && mpz_cmp_si (tmp, __gmpfr_emin-1) < 0)
rnd = GMP_RNDZ;
- inexact = mpfr_set_underflow (y, rnd, MPFR_SIGN (y));
+ inexact = mpfr_underflow (y, rnd, MPFR_SIGN (y));
}
else if (MPFR_UNLIKELY (mpz_cmp_si (tmp, __gmpfr_emax) > 0))
- inexact = mpfr_set_overflow (y, rnd, MPFR_SIGN(x));
+ inexact = mpfr_overflow (y, rnd, MPFR_SIGN(x));
else
MPFR_SET_EXP (y, mpz_get_si (tmp));
mpz_clear (tmp);
@@ -160,7 +160,7 @@ mpfr_pow_z (mpfr_ptr y, mpfr_srcptr x, mpz_srcptr z, mp_rnd_t rnd)
{
/* The following test is necessary because in the rounding to the
- * nearest mode, mpfr_set_underflow always rounds away from 0. In
+ * nearest mode, mpfr_underflow always rounds away from 0. In
* this rounding mode, we need to round to 0 if:
* _ |y| < 2^(emin-2), or